distob package
==============

Submodules
----------

distob.arrays module
--------------------

.. automodule:: distob.arrays
    :members:
    :undoc-members:
    :show-inheritance:

distob.distob module
--------------------

.. automodule:: distob.distob
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: distob
    :members:
    :undoc-members:
    :show-inheritance:
